==> haskell-fdo-notify-0.3.1-734-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-1KIPG302fLzIPIQc9v33gV
key:                  fdo-notify-0.3.1-1KIPG302fLzIPIQc9v33gV
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  7b0bea8996e86f3ed6b2df52e1d2031c
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-9.2.8/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fdo-notify
hs-libraries:         HSfdo-notify-0.3.1-1KIPG302fLzIPIQc9v33gV
depends:
    base-4.16.4.0 containers-0.6.5.1 dbus-1.3.1-FofXUbpNDkm2kZo3hCbqTm

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fdo-notify-0.3.1-736-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-HoAoSht3V8iF5fSUhAHhHY
key:                  fdo-notify-0.3.1-HoAoSht3V8iF5fSUhAHhHY
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  0e16a08d21beea28e96ae1d7722f7c7b
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-9.2.8/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fdo-notify
hs-libraries:         HSfdo-notify-0.3.1-HoAoSht3V8iF5fSUhAHhHY
depends:
    base-4.16.4.0 containers-0.6.5.1 dbus-1.3.1-JSOJ66TQmwtDIsZ24iJUmu

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
